.. Django DDP documentation master file, created by
   sphinx-quickstart on Tue Oct 13 23:24:39 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Installation:
-------------
`Django DDP`_ is available for installation direct from PyPi_:

.. code:: bash

        pip install django-ddp

Links
-----

.. image:: https://readthedocs.org/projects/django-ddp/badge/?version=latest
    :target: https://readthedocs.org/projects/django-ddp/?badge=latest
    :alt: Documentation Status
    :align: right

The latest documentation is available online at 
https://django-ddp.readthedocs.org/.

Source code is available online at https://github.com/commoncode/django-ddp.

Contents
--------

.. toctree::
   :glob:
   :maxdepth: 1

   changelog
   django-ddp*


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

License
=======
.. include:: ../LICENSE

.. _pypi: https://pypi.python.org/pypi/django-ddp
